{% extends "base.html" %}
{% block title %}özgürsözlük{% endblock %}
{% block meta %}
    <meta name="title" content="özgürsözlük">
    <meta name="description" content="{{ description }}">
{% endblock %}
{% block main %}
    <nav>{% include "navigation.html" %}</nav>
    <div class="topic">
        <div class="info">
            <div><p>gündem - <a href="/debe">debe</a></p></div>
            <div>
                {% if p > 1 %}
                    <a href="{{ url_for('index', p=p-1) }}">previous</a>
                    {% if p < 3 %}/{% endif %}
                {% endif %}
                {% if p < 3 %}
                    <a href="{{ url_for('index', p=p+1) }}">next</a>
                {% endif %}
                {% if 3 > 1 %}
                    -
                    <a href="{{ url_for('index', p=3) }}">last page</a>
                {% endif %}
            </div>
        </div>
        {% from "macros.html" import render_gundem %}
        {% for topic in gundem %}
            {% if request.cookies.get('display_pinned_topics') == 'true' %}
                {{ render_gundem(topic) }}
            {% else %}
                {% if not topic.pinned %}
                    {{ render_gundem(topic) }}
                {% endif %}
            {% endif %}
        {% endfor %}
        <div class="info" style="padding-top: 0;">
            <div></div>
            <div>
                {% if p > 1 %}
                    <a href="{{ url_for('index', p=p-1) }}">previous</a>
                    {% if p < 3 %}/{% endif %}
                {% endif %}
                {% if p < 3 %}
                    <a href="{{ url_for('index', p=p+1) }}">next</a>
                {% endif %}
                {% if 3 > 1 %}
                    -
                    <a href="{{ url_for('index', p=3) }}">last page</a>
                {% endif %}
            </div>
        </div>
    </div>
{% endblock %}
