{% extends "base.html" %}
{% block title %}author: {{ author.nickname }} - özgürsözlük{% endblock %}
{% block meta %}
    <meta name="title" content="özgürsözlük">
    <meta name="description" content="{{ author.nickname }} {% if author.level %}({{ author.level }}){% endif %}">
{% endblock %}
{% block main %}
    <nav>{% include "navigation.html" %}</nav>
    <div class="author">
        <img class="avatar" src="{{ author.avatar_url }}">
        <div style="padding: 0 0.5rem 0.5rem 0.5rem;">
            {{ author.nickname }}
            {% if author.level %}
                -
                <span style="opacity: 0.5;">{{ author.level }}</span>
            {% endif %}
            </br>
            <small>{{ author.entry_total_count }} entry</small>
            -
            <small>{{ author.user_follower_count }} follower</small>
            -
            <small>{{ author.user_following_count }} following</small>
            </br></br>
            <a href="{{ url_for('search', q=author.nickname) }}">
                if available go author topic
            </a>
        </div>
    </div>
    {% if author.biography %}
        <div class="author" style="margin: 0 auto;">
            <div style="padding: 0.5rem; text-align: left;">
                {{ author.biography_html|safe }}
            </div>
        </div>
    {% endif %}
{% endblock %}
