{% extends "base.html" %}
{% block title %}{{ entry.topic_title }} - #{{ entry.id }} - özgürsözlük{% endblock %}
{% block meta %}
    <meta name="title" content="özgürsözlük">
    <meta name="description" content="{{ entry.topic_title }} - #{{ entry.id }}">
{% endblock %}
{% block main %}
    <nav>{% include "navigation.html" %}</nav>
    <div class="topic">
        <div class="info">
            <div>
                <p>
                    {{ entry.topic_title }} - şükela:
                    <a href="{{ url_for('topic', path=entry.topic_path, a='nice') }}">nice</a>
                    |
                    <a href="{{ url_for('topic', path=entry.topic_path) }}">all</a>
                </p>
            </div>
        </div>
        {% from "macros.html" import render_entry %}
        {{ render_entry(entry, False) }}
    </div>
{% endblock %}

